# 
## 该文档描述了python 探针版本迭代以及相关功能的变化
## 更多帮助和支持请访问www.tingyun.com 或者直接联系我们的技术支持
#

2015-09-25  Version：0.6.3
--  增加：框架flask的支持, 支持范围0.6以上版本
--  增加：jinja2模板性能检测的支持, 支持范围2.3以上版本
--  修复：默认statuscode造成的服务端数据入库问题
--  增加：支持用户私有化探针

2015-08-28  Version：0.5.4
--  增加：数据库追踪类型
--  增加：cpu、内存的实时采样
--  增加：服务器端配置（参数命名应用过程，暂支持url参数）
--  增加：外部调用redis、requests、httplib2的支持
--  增加：对django框架内部异常采集。

2015-08-06  Version：0.4.3
--  修复：修复在线安装默认配置文件丢失问题
--  修复：线程剖析潜在可能崩溃的bug

2015-08-06  Version：0.4.2
--  增加：性能剖析功能
--  增加：generate-config命令
--  增加：源码安装支持跨目录安装
--  增加：支持pip、easy_install方式安装
--  修复：更详细的python环境信息
--  修复：探针内核修复，增加稳定性
--  修复：其他小细节以及bug

2015-06-29  Version：0.3.0
--  增加：redis的性能数据监测
--  增加：mongodb的性能数据监测
--  增加：增加check-config命令，用于对配置文件进行校验。
